@@ -1,10 +1,8 @@
 
-// dem Sidebarheader eine ID zuweisen => dann per CSS ansprechbar (bei load oder DOMContentLoaded zu spaet)
-//top.document.getElementById("sidebar-throbber").parentNode.setAttribute('id', 'sidebar-header');
-
 window.addEventListener("load", aios_initSidebar, false);
 window.addEventListener("resize", aios_checkThinSwitch, false);
-window.addEventListener("mozfullscreenchange", aios_BrowserFullScreen, false);
+window.addEventListener("fullscreen", aios_BrowserFullScreen, false);
+//window.addEventListener("mozfullscreenchange", aios_BrowserFullScreen, false);
 
 // sonst werden neu definierte Shortcuts bei Browser-Neustart zurueckgesetzt
 extLoad.add(30, function() {
@@ -62,11 +60,6 @@ function aios_getObjects() {
 function aios_initSidebar() {
     aios_getObjects();
 
-    // Toolbarbuttons in der Sidebarheader Toolbar ohne Button-Gedoens anzeigen
-    /*for(var i = 0; i < document.getElementById('aios-sbhtoolbar').childNodes.length; i++) {
-        aios_stripClass(document.getElementById('aios-sbhtoolbar').childNodes[i], 'toolbarbutton-1');
-    }*/
-
     // MacOS X => Tastaturkuerzel ersetzen (Strg. wird durch Command ersetzt und Umschalt durch das Symbol dafuer)
     if(AiOS_HELPER.os == "Darwin") {
         aios_replaceKey('switch-tooltip-box', 'r2c2', 'command');
@@ -101,11 +94,6 @@ function aios_initSidebar() {
     }
 
 
-    // Sidebarheader-Symbolleiste aus der Navigations-Symbolleiste in den Sidebarheader verschieben
-    // wenn die Symbolleiste gleich im Header waere, wuerden keine Icons angezeigt werden, wenn die Sidebar beim Start geschlossen ist
-    //document.getElementById('aios-sbhtoolbox').appendChild(document.getElementById('aios-sbhtoolbar'));
-
-
     // legt commands (Ziele) fuer Manager und Fenster lt. Einstellungen fest
     window.setTimeout(function() {
         aios_setTargets();
@@ -199,8 +187,6 @@ function aios_initSidebar() {
     // Sidebars-Menue ueberwachen - noetig fuer den Fall, dass ein erster Aufruf durch das View-Menue erfolgt
     //fx_sidebarMenu.addEventListener('popupshowing', aios_modSidebarMenu, false);
 
-    // Sidebar-Ladezustand ueberwachen
-    /*document.getElementById('sidebar').addProgressListener(aiosSBListener, Components.interfaces.nsIWebProgress.NOTIFY_STATE_DOCUMENT);*/
 
     // Drag&Drop-Funktion fuer den Sidebar-Umschalter deaktivieren?
     try {
@@ -735,7 +721,7 @@ function aios_BrowserFullScreen() {
 
     // Fullscreen an
     //  => Elemente ausblenden
-    if(document.mozFullScreenElement) {
+    if(document.mozFullScreenElement || window.fullScreen) {
 
         // Fix für mehrmaliges feuern des mozfullscreenchange events
         aios_leaveFullScreen = 0;
@@ -813,4 +799,4 @@ function aios_BrowserFullScreen() {
     aios_adjustToolboxWidth(false);
 
     return true;
-}
\ No newline at end of file
+}
